import { SVG, Text, theme } from "@local-logic/core/ui";
import React from "react";
import {
  scoreCategories,
  scoreCategoriesType,
} from "~/constants/score-categories";
import useTranslator from "~/hooks/useTranslator";
import { translations as scoreGroupTranslations } from "~/localization/translation-packs/scoreGroups";
import * as S from "./styles";
import { useRootElement } from "../context";

export const Tabs = ({
  category,
}: {
  category: Array<scoreCategoriesType>;
}) => {
  const { currentTab } = useRootElement();
  const { translations } = useTranslator([scoreGroupTranslations]);

  const scores = category || scoreCategories;

  return (
    <S.TabsList aria-label="Score tabs">
      {scores.map((tab) => {
        const isActive = tab.value === currentTab;
        const triggerColor = isActive
          ? "--ll-color-primary"
          : "--ll-color-disabled";

        return (
          <React.Fragment key={tab.value}>
            <S.Trigger
              value={tab.value}
              data-cy="score-category-tab"
              data-testid={tab.value}
            >
              <SVG SVGElement={tab.icon} fill={theme[triggerColor]} />
              <Text
                noMargin
                variant="caption1"
                color={triggerColor}
                weight="--ll-font-weight-semibold"
              >
                {translations[tab.value]}
              </Text>
            </S.Trigger>
          </React.Fragment>
        );
      })}
    </S.TabsList>
  );
};
